'''
Created on Oct 6, 2013

@author: me
'''

from django.contrib import admin
from emusic.models import Client, Station, StationPlaylist, Playlist, PlaylistSong, Song, Stat

class StationInline(admin.TabularInline):
    model = Station
    extra = 0
    
class ClientAdmin(admin.ModelAdmin):
    '''
    Admin Client fields display configuration.
    '''
    list_display = ('name', 'station', 'username', 'address', 'contact_name', 'phone1', 'phone2', 'music_info', 'service_info', 'soft_installed')
    list_filter = ('soft_installed',)
    search_fields = ['username']
    inlines = [StationInline,]

class StationAdmin(admin.ModelAdmin):
    '''
    Admin Station fields display configuration.
    '''
    list_display = ['name', 'client', 'hardware_id','licence','station_type','enabled']
    list_filter = ['enabled', 'name', 'client', 'station_type']
    search_fields = ['hardware_id']

class StationPlaylistAdmin(admin.ModelAdmin):
    '''
    Admin StationPlaylist fields display configuration.
    '''
    list_display = ['station', 'hardware', 'playlist_name', 'count', 'syncronized']
    list_filter = ['syncronized']
    search_fields = ['station']
    filter_horizontal = ['playlist']

class PlaylistAdmin(admin.ModelAdmin):
    '''
    Admin Playlist fields display configuration.
    '''
    list_display = ['name','changed']
    list_filter = ['changed']
    search_fields = ['name']

class PlaylistSongAdmin(admin.ModelAdmin):
    '''
    Admin PlaylistSong fields display configuration.
    '''
    list_display = ['playlist', 'count', 'song_name', 'position']
    list_filter = ['playlist']
    search_fields = ['playlist__name']
    filter_horizontal = ['song']


class SongAdmin(admin.ModelAdmin):
    '''
    Admin Song fields display configuration.
    '''
    list_display = ['file_name', 'title', 'artist', 'genre', 
        'song_hash', 'changed','uploaded']
    list_filter = ['changed', 'uploaded']
    search_fields = ['artist', 'title', 'genre', 'file_name']
    #list_per_page = 30

class StatAdmin(admin.ModelAdmin):
    '''
    Admin Stat fields display configuration.
    '''
    list_display = ['station', 'song', 'count']
    list_filter = ['station']
    search_fields = ['station__name', 'song__name']


admin.site.register(Client, ClientAdmin)
admin.site.register(Station, StationAdmin)
admin.site.register(StationPlaylist, StationPlaylistAdmin)
admin.site.register(Playlist, PlaylistAdmin)
admin.site.register(PlaylistSong, PlaylistSongAdmin)
admin.site.register(Song, SongAdmin)
admin.site.register(Stat, StatAdmin)


if __name__ == '__main__':
    pass
