from django.db import models
from django.template.defaultfilters import default
from django.contrib.auth.models import User

# Create your models here.

class Station(models.Model):
    '''
    Define all MusicStore Customer R'Pi Stations.
    '''
    client = models.ForeignKey('Client')
    name = models.CharField(max_length = 100, unique=True)
    hardware_id = models.CharField(max_length = 100, unique=True)
    licence = models.CharField(max_length = 100) 
    station_type = models.BooleanField(default = False)
    enabled = models.BooleanField(default = False)

    def __unicode__(self):
        return unicode(self.name)

class Client(models.Model):
    '''
    Define all MusicStore users.
    '''
    username = models.OneToOneField(User)
    name = models.CharField(max_length = 100, unique=True)
    address = models.CharField(max_length = 100)
    contact_name = models.CharField(max_length = 100)
    phone1 = models.CharField(max_length = 100)
    phone2 = models.CharField(max_length = 100)
    music_info = models.CharField(max_length = 100)
    service_info = models.CharField(max_length = 100)
    soft_installed = models.BooleanField(default = False)
    
    def __unicode__(self):
        return unicode(self.username)
    
    def station(self):
        return "<br />".join(["%s" % obj.hardware_id for obj in Station.objects.filter(client__id = self.id)])
    station.allow_tags = True

class Playlist(models.Model):
    '''
    Define all MusicStore User Playlists.
    '''
    name = models.CharField(max_length = 100, unique=True)
    changed = models.BooleanField(default = False)

    def __unicode__(self):
        return unicode(self.name)

class StationPlaylist(models.Model):
    '''
    Define each Station and Playlist Relation.
    '''
    station = models.ForeignKey(Station)
    playlist = models.ManyToManyField(Playlist)
    syncronized = models.BooleanField(default = False)

    def hardware(self):
        return self.station.hardware_id
    
    def playlist_name(self):
        return "<br />".join(["%s" % obj.name for obj in self.playlist.all()])
    playlist_name.allow_tags = True
    
    def count(self):
        return len(self.playlist.all())

class Song(models.Model):
    '''
    Define all MusicStore Songs table.
    '''
    artist = models.CharField(max_length = 100)
    title = models.CharField(max_length = 100, unique=True)
    genre = models.CharField(max_length = 100)
    file_name = models.CharField(max_length = 100, unique=True)
    song_hash = models.CharField(max_length = 100)
    changed = models.BooleanField(default = False)
    uploaded = models.BooleanField(default = False)

    def __unicode__(self):
        return unicode(self.title)

class PlaylistSong(models.Model):
    '''
    Define Playlist and Song Relation table.
    '''
    playlist = models.ForeignKey(Playlist, unique=True)
    song = models.ManyToManyField(Song)
    position = models.IntegerField(default = 0)

    def __unicode__(self):
        return unicode(self.playlist)

    def count(self):
        return len(self.song.all())

    def song_name(self):
        return "<br />".join(["%s" % obj.title for obj in self.song.all()])
    song_name.allow_tags = True


class Stat(models.Model):
    '''
    Define Station and Song Relation with statistics.
    '''
    station = models.ForeignKey(Station)
    song = models.ForeignKey(Song)
    count = models.IntegerField()
    
    def __unicode__(self):
        return unicode(self.station)
    
